@@ -1,3 +1,9 @@
+# Copyright (c) 2008, 2012 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2014, 2016-2017 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
+
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
 
@@ -5,18 +11,14 @@ import sys
 
 from .__pkginfo__ import version as __version__
 
+
 def run_pylint():
     """run pylint"""
     from pylint.lint import Run
-    Run(sys.argv[1:])
-
-def run_pylint_gui():
-    """run pylint-gui"""
     try:
-        from pylint.gui import Run
         Run(sys.argv[1:])
-    except ImportError:
-        sys.exit('tkinter is not available')
+    except KeyboardInterrupt:
+        sys.exit(1)
 
 def run_epylint():
     """run pylint"""
