@@ -91,8 +91,8 @@ class SnakeCaseStyle(NamingStyle):
     MOD_NAME_RGX = re.compile('([a-z_][a-z0-9_]*)$')
     CONST_NAME_RGX = re.compile('(([a-z_][a-z0-9_]*)|(__.*__))$')
     COMP_VAR_RGX = re.compile('[a-z_][a-z0-9_]*$')
-    DEFAULT_NAME_RGX = re.compile('(([a-z_][a-z0-9_]{2,30})|(_[a-z0-9_]*)|(__[a-z][a-z0-9_]+__))$')
-    CLASS_ATTRIBUTE_RGX = re.compile(r'(([a-z_][a-z0-9_]{2,30}|(__.*__)))$')
+    DEFAULT_NAME_RGX = re.compile('(([a-z_][a-z0-9_]{2,})|(_[a-z0-9_]*)|(__[a-z][a-z0-9_]+__))$')
+    CLASS_ATTRIBUTE_RGX = re.compile(r'(([a-z_][a-z0-9_]{2,}|(__.*__)))$')
 
 
 class CamelCaseStyle(NamingStyle):
@@ -101,8 +101,8 @@ class CamelCaseStyle(NamingStyle):
     MOD_NAME_RGX = re.compile('([a-z_][a-zA-Z0-9]*)$')
     CONST_NAME_RGX = re.compile('(([a-z_][A-Za-z0-9]*)|(__.*__))$')
     COMP_VAR_RGX = re.compile('[a-z_][A-Za-z0-9]*$')
-    DEFAULT_NAME_RGX = re.compile('(([a-z_][a-zA-Z0-9]{2,30})|(__[a-z][a-zA-Z0-9_]+__))$')
-    CLASS_ATTRIBUTE_RGX = re.compile(r'([a-z_][A-Za-z0-9]{2,30}|(__.*__))$')
+    DEFAULT_NAME_RGX = re.compile('(([a-z_][a-zA-Z0-9]{2,})|(__[a-z][a-zA-Z0-9_]+__))$')
+    CLASS_ATTRIBUTE_RGX = re.compile(r'([a-z_][A-Za-z0-9]{2,}|(__.*__))$')
 
 
 class PascalCaseStyle(NamingStyle):
@@ -111,8 +111,8 @@ class PascalCaseStyle(NamingStyle):
     MOD_NAME_RGX = re.compile('[A-Z_][a-zA-Z0-9]+$')
     CONST_NAME_RGX = re.compile('(([A-Z_][A-Za-z0-9]*)|(__.*__))$')
     COMP_VAR_RGX = re.compile('[A-Z_][a-zA-Z0-9]+$')
-    DEFAULT_NAME_RGX = re.compile('[A-Z_][a-zA-Z0-9]{2,30}$|(__[a-z][a-zA-Z0-9_]+__)$')
-    CLASS_ATTRIBUTE_RGX = re.compile('[A-Z_][a-zA-Z0-9]{2,30}$')
+    DEFAULT_NAME_RGX = re.compile('[A-Z_][a-zA-Z0-9]{2,}$|(__[a-z][a-zA-Z0-9_]+__)$')
+    CLASS_ATTRIBUTE_RGX = re.compile('[A-Z_][a-zA-Z0-9]{2,}$')
 
 
 class UpperCaseStyle(NamingStyle):
@@ -121,8 +121,8 @@ class UpperCaseStyle(NamingStyle):
     MOD_NAME_RGX = re.compile('[A-Z_][A-Z0-9_]+$')
     CONST_NAME_RGX = re.compile('(([A-Z_][A-Z0-9_]*)|(__.*__))$')
     COMP_VAR_RGX = re.compile('[A-Z_][A-Z0-9_]+$')
-    DEFAULT_NAME_RGX = re.compile('([A-Z_][A-Z0-9_]{2,30})|(__[a-z][a-zA-Z0-9_]+__)$')
-    CLASS_ATTRIBUTE_RGX = re.compile('[A-Z_][A-Z0-9_]{2,30}$')
+    DEFAULT_NAME_RGX = re.compile('([A-Z_][A-Z0-9_]{2,})|(__[a-z][a-zA-Z0-9_]+__)$')
+    CLASS_ATTRIBUTE_RGX = re.compile('[A-Z_][A-Z0-9_]{2,}$')
 
 
 class AnyStyle(NamingStyle):
@@ -828,6 +828,12 @@ class BasicChecker(_BasicChecker):
                   'Used when the first argument to reversed() builtin '
                   'isn\'t a sequence (does not implement __reversed__, '
                   'nor __getitem__ and __len__'),
+        'E0119': ('format function is not called on str',
+                  'misplaced-format-function',
+                  'Emitted when format function is not called on str object. '
+                  'e.g doing print("value: {}").format(123) instead of '
+                  'print("value: {}".format(123)). This might not be what the user '
+                  'intended to do.'),
     }
 
     reports = (('RP0101', 'Statistics by type', report_by_type_stats),)
@@ -1098,11 +1104,31 @@ class BasicChecker(_BasicChecker):
         """just print a warning on exec statements"""
         self.add_message('exec-used', node=node)
 
-    @utils.check_messages('eval-used', 'exec-used', 'bad-reversed-sequence')
+    def _check_misplaced_format_function(self, call_node):
+        if not isinstance(call_node.func, astroid.Attribute):
+            return
+        if call_node.func.attrname != 'format':
+            return
+
+        expr = utils.safe_infer(call_node.func.expr)
+        if expr is astroid.Uninferable:
+            return
+        if not expr:
+            # we are doubtful on inferred type of node, so here just check if format
+            # was called on print()
+            call_expr = call_node.func.expr
+            if not isinstance(call_expr, astroid.Call):
+                return
+            if isinstance(call_expr.func, astroid.Name) and call_expr.func.name == 'print':
+                self.add_message('misplaced-format-function', node=call_node)
+
+    @utils.check_messages('eval-used', 'exec-used', 'bad-reversed-sequence',
+                          'misplaced-format-function')
     def visit_call(self, node):
         """visit a Call node -> check if this is not a blacklisted builtin
         call and check for * or ** use
         """
+        self._check_misplaced_format_function(node)
         if isinstance(node.func, astroid.Name):
             name = node.func.name
             # ignore the name if it's not a builtin (i.e. not defined in the
@@ -1343,7 +1369,8 @@ class NameChecker(_BasicChecker):
                  'metavar': '<decorator names>',
                  'help': 'List of decorators that produce properties, such as '
                          'abc.abstractproperty. Add to this list to register '
-                         'other decorators that produce valid properties.'}
+                         'other decorators that produce valid properties. '
+                         'These decorators are taken in consideration only for invalid-name.'}
                ),
               ) + _create_naming_options()
 
@@ -1849,8 +1876,8 @@ class ComparisonChecker(_BasicChecker):
         left_operand, right_operand = node.left, node.ops[0][1]
         # this message should be emitted only when there is comparison of bare callable
         # with non bare callable.
-        if sum([1 for operand in (left_operand, right_operand)
-                if isinstance(utils.safe_infer(operand), bare_callables)]) == 1:
+        if sum(1 for operand in (left_operand, right_operand)
+               if isinstance(utils.safe_infer(operand), bare_callables)) == 1:
             self.add_message('comparison-with-callable', node=node)
 
     @utils.check_messages('singleton-comparison', 'misplaced-comparison-constant',
