@@ -88,12 +88,6 @@ MSGS = {
               'a bare raise inside a finally clause, which might work, as long '
               'as an exception is raised inside the try block, but it is '
               'nevertheless a code smell that must not be relied upon.'),
-    'E0705': ('The except handler raises immediately',
-              'try-except-raise',
-              'Used when an except handler uses raise as its first or only '
-              'operator. This is useless because it raises back the exception '
-              'immediately. Remove the raise operator or the entire '
-              'try-except-raise block!'),
     'E0710': ('Raising a new style class which doesn\'t inherit from BaseException',
               'raising-non-exception',
               'Used when a new style class which doesn\'t inherit from \
@@ -118,6 +112,12 @@ MSGS = {
               'duplicate-except',
               'Used when an except catches a type that was already caught by '
               'a previous handler.'),
+    'W0706': ('The except handler raises immediately',
+              'try-except-raise',
+              'Used when an except handler uses raise as its first or only '
+              'operator. This is useless because it raises back the exception '
+              'immediately. Remove the raise operator or the entire '
+              'try-except-raise block!'),
     'W0710': ('Exception doesn\'t inherit from standard "Exception" class',
               'nonstandard-exception',
               'Used when a custom exception class is raised but doesn\'t \
@@ -357,20 +357,44 @@ class ExceptionsChecker(checkers.BaseChecker):
                                  node=handler.type,
                                  args=(exc.name, ))
 
+    def _check_try_except_raise(self, node):
+        bare_raise = False
+        handler_having_bare_raise = None
+        handler_type_having_bare_raise = None
+        for handler in node.handlers:
+            if bare_raise:
+                # check that subsequent handler is not parent of handler which had bare raise.
+                # since utils.safe_infer can fail for bare except, check it before.
+                # also break early if bare except is followed by bare except.
+
+                if (not handler.type or
+                        handler_type_having_bare_raise and
+                        utils.is_subclass_of(handler_type_having_bare_raise,
+                                             utils.safe_infer(handler.type))):
+                    bare_raise = False
+                    break
+            # `raise` as the first operator inside the except handler
+            if utils.is_raising([handler.body[0]]):
+                # flags when there is a bare raise
+                if handler.body[0].exc is None:
+                    bare_raise = True
+                    handler_having_bare_raise = handler
+                    if handler_having_bare_raise.type:
+                        handler_type_having_bare_raise = utils.safe_infer(
+                            handler_having_bare_raise.type)
+
+        if bare_raise:
+            self.add_message('try-except-raise', node=handler_having_bare_raise)
+
     @utils.check_messages('bare-except', 'broad-except', 'try-except-raise',
                           'binary-op-exception', 'bad-except-order',
                           'catching-non-exception', 'duplicate-except')
     def visit_tryexcept(self, node):
         """check for empty except"""
+        self._check_try_except_raise(node)
         exceptions_classes = []
         nb_handlers = len(node.handlers)
         for index, handler in enumerate(node.handlers):
-            # `raise` as the first operator inside the except handler
-            if utils.is_raising([handler.body[0]]):
-                # flags when there is a bare raise
-                if handler.body[0].exc is None:
-                    self.add_message('try-except-raise', node=handler)
-
             if handler.type is None:
                 if not utils.is_raising(handler.body):
                     self.add_message('bare-except', node=handler)
