@@ -83,6 +83,7 @@ def _is_builtin(node):
 _ACCEPTS_ITERATOR = {'iter', 'list', 'tuple', 'sorted', 'set', 'sum', 'any',
                      'all', 'enumerate', 'dict', 'filter', 'reversed',
                      'max', 'min', 'frozenset'}
+ATTRIBUTES_ACCEPTS_ITERATOR = {'join', 'from_iterable'}
 _BUILTIN_METHOD_ACCEPTS_ITERATOR = {
     'builtins.list.extend',
     'builtins.dict.update',
@@ -115,7 +116,7 @@ def _in_iterating_context(node):
             if _is_builtin(parent_scope) and parent.func.name in _ACCEPTS_ITERATOR:
                 return True
         elif isinstance(parent.func, astroid.Attribute):
-            if parent.func.attrname == 'join':
+            if parent.func.attrname in ATTRIBUTES_ACCEPTS_ITERATOR:
                 return True
             try:
                 inferred = next(parent.func.infer())
