@@ -100,7 +100,7 @@ class RefactoringChecker(checkers.BaseTokenChecker):
                   'a handful of name binding operations, such as for iteration, '
                   'with statement assignment and exception handler assignment.'
                  ),
-        'R1705': ('Unnecessary "else" after "return"',
+        'R1705': ('Unnecessary "%s" after "return"',
                   'no-else-return',
                   'Used in order to highlight an unnecessary block of '
                   'code following an if containing a return statement. '
@@ -230,7 +230,6 @@ class RefactoringChecker(checkers.BaseTokenChecker):
         Unfortunately we need to know the exact type in certain
         cases.
         """
-
         if isinstance(node.parent, astroid.If):
             orelse = node.parent.orelse
             # current if node must directly follow an "else"
@@ -345,7 +344,8 @@ class RefactoringChecker(checkers.BaseTokenChecker):
         if not isinstance(scope, astroid.FunctionDef):
             return
 
-        for defined_argument in scope.args.nodes_of_class(astroid.AssignName):
+        for defined_argument in scope.args.nodes_of_class(astroid.AssignName,
+                                                          skip_klass=(astroid.Lambda, )):
             if defined_argument.name == name_node.name:
                 self.add_message('redefined-argument-from-local',
                                  node=name_node,
@@ -378,7 +378,12 @@ class RefactoringChecker(checkers.BaseTokenChecker):
             return
 
         if _if_statement_is_always_returning(node) and not self._is_actual_elif(node):
-            self.add_message('no-else-return', node=node)
+            orelse = node.orelse and node.orelse[0]
+            followed_by_elif = (orelse.lineno, orelse.col_offset) in self._elifs
+            self.add_message(
+                'no-else-return', node=node,
+                args='elif' if followed_by_elif else 'else',
+            )
 
     def _check_consider_get(self, node):
         def type_and_name_are_equal(node_a, node_b):
@@ -804,10 +809,8 @@ class RefactoringChecker(checkers.BaseTokenChecker):
         return condition, true_value, false_value
 
     def visit_functiondef(self, node):
-        self._return_nodes[node.name] = []
-        return_nodes = node.nodes_of_class(astroid.Return)
-        self._return_nodes[node.name] = [_rnode for _rnode in return_nodes
-                                         if _rnode.frame() == node.frame()]
+        self._return_nodes[node.name] = list(
+            node.nodes_of_class(astroid.Return, skip_klass=astroid.FunctionDef))
 
     def _check_consistent_returns(self, node):
         """Check that all return statements inside a function are consistent.
@@ -918,8 +921,7 @@ class RefactoringChecker(checkers.BaseTokenChecker):
         """
         if len(self._return_nodes[node.name]) > 1:
             return
-
-        if not node.body:
+        if len(node.body) <= 1:
             return
 
         last = node.body[-1]
@@ -1238,9 +1240,11 @@ def is_trailing_comma(tokens, index):
             if token.type in (tokenize.NEWLINE, tokenize.NL):
                 return index - subindex
         return 0
+
     curline_start = get_curline_index_start()
+    expected_tokens = {'return', 'yield'}
     for prevtoken in tokens[curline_start:index]:
-        if '=' in prevtoken.string or prevtoken.string == 'return':
+        if '=' in prevtoken.string or prevtoken.string in expected_tokens:
             return True
     return False
 
