@@ -8,6 +8,9 @@
 # Copyright (c) 2016 Alexander Todorov <atodorov@otb.bg>
 # Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
 # Copyright (c) 2017 Mikhail Fesenko <proggga@gmail.com>
+# Copyright (c) 2018 Mike Frysinger <vapier@gmail.com>
+# Copyright (c) 2018 Sushobhit <31987769+sushobhit27@users.noreply.github.com>
+# Copyright (c) 2018 Anthony Sottile <asottile@umich.edu>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -38,12 +41,9 @@ except ImportError:
         pass
 
 
-import six
-
 from pylint.interfaces import ITokenChecker, IAstroidChecker
 from pylint.checkers import BaseTokenChecker
 from pylint.checkers.utils import check_messages
-from pylint.utils import safe_decode
 
 if enchant is not None:
     br = enchant.Broker()
@@ -164,7 +164,7 @@ class SpellingChecker(BaseTokenChecker):
                 {'default' : '', 'type' : 'choice', 'metavar' : '<dict name>',
                  'choices': dict_choices,
                  'help' : 'Spelling dictionary name. '
-                          'Available dictionaries: %s.%s' % (dicts, instr)}),
+                          'Available dictionaries: %s.%s.' % (dicts, instr)}),
                ('spelling-ignore-words',
                 {'default' : '',
                  'type' : 'string',
@@ -186,7 +186,7 @@ class SpellingChecker(BaseTokenChecker):
                ('max-spelling-suggestions',
                 {'default': 4, 'type': 'int', 'metavar': 'N',
                  'help': 'Limits count of emitted suggestions for '
-                         'spelling mistakes'}),
+                         'spelling mistakes.'}),
               )
 
     def open(self):
@@ -243,10 +243,7 @@ class SpellingChecker(BaseTokenChecker):
         else:
             starts_with_comment = False
         for word, _ in self.tokenizer(line.strip()):
-            if six.PY2:
-                lower_cased_word = word.lower()
-            else:
-                lower_cased_word = word.casefold()
+            lower_cased_word = word.casefold()
 
             # Skip words from ignore list.
             if word in self.ignore_list or lower_cased_word in self.ignore_list:
@@ -297,7 +294,7 @@ class SpellingChecker(BaseTokenChecker):
                 self.add_message(msgid, line=line_num,
                                  args=(word, original_line,
                                        indicator,
-                                       "'{0}'".format("' or '".join(suggestions))))
+                                       "'{}'".format("' or '".join(suggestions))))
 
     def process_tokens(self, tokens):
         if not self.initialized:
@@ -342,9 +339,6 @@ class SpellingChecker(BaseTokenChecker):
             return
 
         start_line = node.lineno + 1
-        if six.PY2:
-            encoding = node.root().file_encoding
-            docstring = safe_decode(docstring, encoding, 'replace')
 
         # Go through lines of docstring
         for idx, line in enumerate(docstring.splitlines()):
