@@ -1,5 +1,21 @@
-# Copyright (c) 2012-2016 Google, Inc.
-# http://www.logilab.fr/ -- mailto:contact@logilab.fr
+# -*- coding: utf-8 -*-
+# Copyright (c) 2013-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2013-2014 Google, Inc.
+# Copyright (c) 2014-2018 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014 Cosmin Poieana <cmin@ropython.org>
+# Copyright (c) 2014 Vlad Temian <vladtemian@gmail.com>
+# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
+# Copyright (c) 2015 Cezar <celnazli@bitdefender.com>
+# Copyright (c) 2015 Chris Rebert <code@rebertia.com>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2016 Jared Garst <cultofjared@gmail.com>
+# Copyright (c) 2017 Renat Galimov <renat2017@gmail.com>
+# Copyright (c) 2017 Martin <MartinBasti@users.noreply.github.com>
+# Copyright (c) 2017 Christopher Zurcher <zurcher@users.noreply.github.com>
+# Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
+# Copyright (c) 2018 Banjamin Freeman <befreeman@users.noreply.github.com>
+# Copyright (c) 2018 Ioana Tagirta <ioana.tagirta@gmail.com>
+
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
 
@@ -7,10 +23,9 @@
 
 import sys
 
-import six
-
 import astroid
 from astroid.bases import Instance
+from astroid.node_classes import Const
 from pylint.interfaces import IAstroidChecker
 from pylint.checkers import BaseChecker
 from pylint.checkers import utils
@@ -18,6 +33,12 @@ from pylint.checkers import utils
 
 OPEN_FILES = {'open', 'file'}
 UNITTEST_CASE = 'unittest.case'
+THREADING_THREAD = 'threading.Thread'
+COPY_COPY = 'copy.copy'
+OS_ENVIRON = 'os._Environ'
+ENV_GETTERS = {'os.getenv'}
+SUBPROCESS_POPEN = 'subprocess.Popen'
+
 if sys.version_info >= (3, 0):
     OPEN_MODULE = '_io'
 else:
@@ -26,15 +47,12 @@ else:
 
 def _check_mode_str(mode):
     # check type
-    if not isinstance(mode, six.string_types):
+    if not isinstance(mode, str):
         return False
     # check syntax
     modes = set(mode)
-    _mode = "rwatb+U"
-    creating = False
-    if six.PY3:
-        _mode += "x"
-        creating = "x" in modes
+    _mode = "rwatb+Ux"
+    creating = "x" in modes
     if modes - set(_mode) or len(mode) > len(modes):
         return False
     # check logic
@@ -44,25 +62,16 @@ def _check_mode_str(mode):
     text = "t" in modes
     binary = "b" in modes
     if "U" in modes:
-        if writing or appending or creating and six.PY3:
+        if writing or appending or creating:
             return False
         reading = True
-        if not six.PY3:
-            binary = True
     if text and binary:
         return False
-    total = reading + writing + appending + (creating if six.PY3 else 0)
+    total = reading + writing + appending + creating
     if total > 1:
         return False
-    if not (reading or writing or appending or creating and six.PY3):
+    if not (reading or writing or appending or creating):
         return False
-    # other 2.x constraints
-    if not six.PY3:
-        if "U" in mode:
-            mode = mode.replace("U", "")
-            if "r" not in mode:
-                mode = "r" + mode
-        return mode[0] in ("r", "w", "a", "U")
     return True
 
 
@@ -95,6 +104,35 @@ class StdlibChecker(BaseChecker):
                   'The method is marked as deprecated and will be removed in '
                   'a future version of Python. Consider looking for an '
                   'alternative in the documentation.'),
+        'W1506': ('threading.Thread needs the target function',
+                  'bad-thread-instantiation',
+                  'The warning is emitted when a threading.Thread class '
+                  'is instantiated without the target function being passed. '
+                  'By default, the first parameter is the group param, not the target param. '),
+        'W1507': ('Using copy.copy(os.environ). Use os.environ.copy() '
+                  'instead. ',
+                  'shallow-copy-environ',
+                  'os.environ is not a dict object but proxy object, so '
+                  'shallow copy has still effects on original object. '
+                  'See https://bugs.python.org/issue15373 for reference. '),
+        'E1507': ('%s does not support %s type argument',
+                  'invalid-envvar-value',
+                  'Env manipulation functions support only string type arguments. '
+                  'See https://docs.python.org/3/library/os.html#os.getenv. '),
+        'W1508': ('%s default type is %s. Expected str or None.',
+                  'invalid-envvar-default',
+                  'Env manipulation functions return None or str values. '
+                  'Supplying anything different as a default may cause bugs. '
+                  'See https://docs.python.org/3/library/os.html#os.getenv. '),
+        'W1509': ('Using preexec_fn keyword which may be unsafe in the presence '
+                  'of threads',
+                  'subprocess-popen-preexec-fn',
+                  'The preexec_fn parameter is not safe to use in the presence '
+                  'of threads in your application. The child process could '
+                  'deadlock before exec is called. If you must use it, keep it '
+                  'trivial! Minimize the number of libraries you call into.'
+                  'https://docs.python.org/3/library/subprocess.html#popen-constructor'),
+
     }
 
     deprecated = {
@@ -161,25 +199,64 @@ class StdlibChecker(BaseChecker):
             ],
             (3, 5, 0): [
                 'fractions.gcd',
-                'inspect.getfullargspec', 'inspect.getargvalues',
+                'inspect.getargvalues',
                 'inspect.formatargspec', 'inspect.formatargvalues',
                 'inspect.getcallargs',
                 'platform.linux_distribution', 'platform.dist',
             ],
+            (3, 6, 0): [
+                'importlib._bootstrap_external.FileLoader.load_module',
+            ],
         },
     }
 
-    @utils.check_messages('bad-open-mode', 'redundant-unittest-assert',
-                          'deprecated-method')
+    def _check_bad_thread_instantiation(self, node):
+        if not node.kwargs and not node.keywords and len(node.args) <= 1:
+            self.add_message('bad-thread-instantiation', node=node)
+
+    def _check_for_preexec_fn_in_Popen(self, node):
+        if node.keywords:
+            for keyword in node.keywords:
+                if keyword.arg == 'preexec_fn':
+                    self.add_message('subprocess-popen-preexec-fn', node=node)
+
+    def _check_shallow_copy_environ(self, node):
+        arg = utils.get_argument_from_call(node, position=0)
+        for inferred in arg.inferred():
+            if inferred.qname() == OS_ENVIRON:
+                self.add_message('shallow-copy-environ', node=node)
+                break
+
+    @utils.check_messages('bad-open-mode',
+                          'redundant-unittest-assert',
+                          'deprecated-method',
+                          'bad-thread-instantiation',
+                          'shallow-copy-environ',
+                          'invalid-envvar-value',
+                          'invalid-envvar-default',
+                          'subprocess-popen-preexec-fn')
     def visit_call(self, node):
-        """Visit a CallFunc node."""
+        """Visit a Call node."""
         try:
             for inferred in node.func.infer():
-                if inferred.root().name == OPEN_MODULE:
+                if inferred is astroid.Uninferable:
+                    continue
+                elif inferred.root().name == OPEN_MODULE:
                     if getattr(node.func, 'name', None) in OPEN_FILES:
                         self._check_open_mode(node)
-                if inferred.root().name == UNITTEST_CASE:
+                elif inferred.root().name == UNITTEST_CASE:
                     self._check_redundant_assert(node, inferred)
+                elif isinstance(inferred, astroid.ClassDef):
+                    if inferred.qname() == THREADING_THREAD:
+                        self._check_bad_thread_instantiation(node)
+                    elif inferred.qname() == SUBPROCESS_POPEN:
+                        self._check_for_preexec_fn_in_Popen(node)
+                elif isinstance(inferred, astroid.FunctionDef):
+                    name = inferred.qname()
+                    if name == COPY_COPY:
+                        self._check_shallow_copy_environ(node)
+                    elif name in ENV_GETTERS:
+                        self._check_env_function(node, inferred)
                 self._check_deprecated_method(node, inferred)
         except astroid.InferenceError:
             return
@@ -265,6 +342,61 @@ class StdlibChecker(BaseChecker):
                 self.add_message('bad-open-mode', node=node,
                                  args=mode_arg.value)
 
+    def _check_env_function(self, node, infer):
+        env_name_kwarg = 'key'
+        env_value_kwarg = 'default'
+        if node.keywords:
+            kwargs = {keyword.arg: keyword.value for keyword in node.keywords}
+        else:
+            kwargs = None
+        if node.args:
+            env_name_arg = node.args[0]
+        elif kwargs and env_name_kwarg in kwargs:
+            env_name_arg = kwargs[env_name_kwarg]
+        else:
+            env_name_arg = None
+
+        if env_name_arg:
+            self._check_invalid_envvar_value(
+                node=node,
+                message='invalid-envvar-value',
+                call_arg=utils.safe_infer(env_name_arg),
+                infer=infer,
+                allow_none=False
+            )
+
+        if len(node.args) == 2:
+            env_value_arg = node.args[1]
+        elif kwargs and env_value_kwarg in kwargs:
+            env_value_arg = kwargs[env_value_kwarg]
+        else:
+            env_value_arg = None
+
+        if env_value_arg:
+            self._check_invalid_envvar_value(
+                node=node,
+                infer=infer,
+                message='invalid-envvar-default',
+                call_arg=utils.safe_infer(env_value_arg),
+                allow_none=True,
+            )
+
+    def _check_invalid_envvar_value(self, node, infer, message, call_arg, allow_none):
+        if call_arg in (astroid.Uninferable, None):
+            return
+
+        name = infer.qname()
+        if isinstance(call_arg, Const):
+            emit = False
+            if call_arg.value is None:
+                emit = not allow_none
+            elif not isinstance(call_arg.value, str):
+                emit = True
+            if emit:
+                self.add_message(message, node=node, args=(name, call_arg.pytype()))
+        else:
+            self.add_message(message, node=node, args=(name, call_arg.pytype()))
+
 
 def register(linter):
     """required method to auto register this checker """
