@@ -1,3 +1,9 @@
+# -*- coding: utf-8 -*-
+# Copyright (c) 2015 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2016-2017 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2016 Glenn Matthews <glmatthe@cisco.com>
+# Copyright (c) 2018 Ville Skyttä <ville.skytta@upcloud.com>
+
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
 
@@ -8,11 +14,11 @@ from pylint.interfaces import ITokenChecker, IAstroidChecker
 
 
 class ElseifUsedChecker(BaseTokenChecker):
-    """Checks for use of "else if" when a "elif" could be used
+    """Checks for use of "else if" when an "elif" could be used
     """
 
     __implements__ = (ITokenChecker, IAstroidChecker)
-    name = 'elseifused'
+    name = 'else_if_used'
     msgs = {'R5501': ('Consider using "elif" instead of "else if"',
                       'else-if-used',
                       'Used when an else statement is immediately followed by '
@@ -49,7 +55,7 @@ class ElseifUsedChecker(BaseTokenChecker):
     def visit_if(self, node):
         if isinstance(node.parent, astroid.If):
             orelse = node.parent.orelse
-            # current if node must directly follow a "else"
+            # current if node must directly follow an "else"
             if orelse and orelse == [node]:
                 if not self._elifs[self._if_counter]:
                     self.add_message('else-if-used', node=node)
