@@ -1,4 +1,7 @@
 # Copyright (c) 2015-2016 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2018 ssolanki <sushobhitsolanki@gmail.com>
+# Copyright (c) 2018 Sushobhit <31987769+sushobhit27@users.noreply.github.com>
+# Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -8,10 +11,8 @@
 A micro report is a tree of layout and content objects.
 """
 
-from six import string_types
 
-
-class VNode(object):
+class VNode:
 
     def __init__(self, nid=None):
         self.id = nid
@@ -39,7 +40,9 @@ class VNode(object):
         visitor
         """
         try:
+            # pylint: disable=no-member
             return self.TYPE.replace('-', '_')
+        # pylint: disable=broad-except
         except Exception:
             return self.__class__.__name__.lower()
 
@@ -95,7 +98,7 @@ class Text(VNode):
         super(Text, self).__init__(**kwargs)
         #if isinstance(data, unicode):
         #    data = data.encode('ascii')
-        assert isinstance(data, string_types), data.__class__
+        assert isinstance(data, str), data.__class__
         self.escaped = escaped
         self.data = data
 
