@@ -1,5 +1,5 @@
 """Errors for invalid sequence indices"""
-# pylint: disable=too-few-public-methods, no-self-use, import-error, missing-docstring
+# pylint: disable=too-few-public-methods, no-self-use, import-error, missing-docstring, useless-object-inheritance
 import six
 from unknown import Unknown
 
@@ -53,7 +53,7 @@ def function9():
     return TESTLIST[0]  # no error
 
 def function10():
-    """list index is a integer expression"""
+    """list index is an integer expression"""
     return TESTLIST[int(0.0)] # no error
 
 def function11():
