@@ -1,5 +1,5 @@
-# pylint: disable=missing-docstring, broad-except, unreachable
-# pylint: disable=unused-variable, too-few-public-methods, invalid-name
+# pylint: disable=missing-docstring, broad-except, unreachable, try-except-raise
+# pylint: disable=unused-variable, too-few-public-methods, invalid-name, useless-object-inheritance
 
 try:
     raise # [misplaced-bare-raise]
@@ -73,3 +73,13 @@ class ContextManager(object):
         return self
     def __exit__(self, *args):
         raise
+
+
+def test_dont_trigger_in_finally_clause_found_in_exception_handler():
+    try:
+        raise ValueError('bad value')
+    except ValueError:
+        try:
+            raise IOError('failed')
+        finally:
+            raise
