@@ -212,6 +212,11 @@ class TestPython3Checker(testutils.CheckerTestCase):
             'set().update({}())',
             '[].extend({}())',
             '{{}}.update({}())',
+            '''
+            from __future__ import absolute_import
+            from itertools import chain
+            chain.from_iterable({}())
+            ''',
         ]
         non_iterating_code = [
             'x = __({}())',
